.TH PATHUTIL 3 "October 18, 1990" "NeXT Computer, Inc."
.SH NAME
.nh
absolutePath, basename, directoryApply, directoryUnlink, 
filenameToRegex, fullPath, parentname, pwd \- path utilities
.SH SYNOPSIS
.B #include <text/pathutil.h>
.PP
.SH DESCRIPTION
.nh
These functions manage and manipulate file system paths. 
They are part of the common text library, libtext. 
.SH SUMMARY
.PP
.nh
char *\fBabsolutePath\fR(char *\fIs\fR);
.in +.5in
.sp
Returns the absolute path of \fIs\fR, 
resolving links and eliminating references to "." and "..".
Does not understand "~".
.in -.5in
.PP
.nh
char *\fBbasename\fR(char *\fIs\fR);
.in +.5in
.sp
Returns a pointer to the base component of \fIs\fR.
.in -.5in
.PP
.nh
int \fBdirectoryApply\fR(char *\fIname\fR, void *\fIinfo\fR, 
.br
.in +1in
int (*\fIf\fR)(char *\fIparent\fR, char *\fIfile\fR, 
struct statbuf *\fIb\fR, void *\fIinfo\fR), 
char \fIrecurse\fR, char \fIdepthFirst\fR, char \fIpreDescent\fR);
.in -1in
.in +.5in
.sp
Enumerates the paths in directory \fIname\fR, 
visiting each file or directory exactly once, 
and applies \fIf\fR to each path enumerated.
The return value is positive if all calls to \fIf\fR 
return positive values, 
or the first non-positive value returned by \fIf\fR otherwise.
\fIf\fR should return a negative value in the event of an error; 
this will interrupt the enumeration.
A zero return from \fIf\fR interrupts the enumeration 
if the path under consideration is not a directory.
A zero return from \fIf\fR for a path describing a directory
prevents descent into the subtree rooted at that directory, 
but does not interrupt the enumeration.
\fIrecurse\fR controls recursion and directory descent as follows
.in +.5in
.sp
.nf
0		no descent into directories
1		enables descent into directories
2		enables descent into directories and symbolic links
add 8	restricts the enumeration to directories only
.fi
.sp
.in -.5in
If \fIdepthFirst\fR is true, \fBdirectoryApply\fR descends into 
directories as they are encountered; 
otherwise, it buffers the names of directories as they are encountered, 
then descends into those directories 
when the contents of the current directory have been fully enumerated.
If \fIpreDescent\fR is true, \fBdirectoryApply\fR visits 
directories \fIbefore\fR enumerating their contents, rather than \fIafter\fR.
Multiple links to a file are visited independently;
the contents of a directory are enumerated only once, however, 
even if the directory itsself is visited through more than one link.
.in -.5in
.PP
int \fBdirectoryUnlink\fR(char *\fIname\fR, void *\fIinfo\fR, 
.br
.in +1in
int (*\fIf\fR)(char *\fIparent\fR, char *\fIfile\fR, 
struct statbuf *\fIb\fR, void *\fIinfo\fR), 
char \fIrecurse\fR, char \fIdepthFirst\fR, char \fIremove\fR);
.in -1in
.in +.5in
.sp
Recursively unlinks files in the directory tree rooted at \fIname\fR. 
Calls \fIf\fR, if supplied, for confirmation on each file.
\fIf\fR should return a non-zero value 
to confirm the removal of "\fIparent/file\fR", or zero to decline.
\fIrecurse\fR and \fIdepthFirst\fR are passed to \fBdirectoryApply\fR.
If \fIremove\fR is true, directories are removed after their contents 
have been destroyed, otherwise, the directory structure is left intact.
Returns a negative value in the event of an error.
.in -.5in
.PP
.nh
char *\fBfilenameToRegex\fR(char *\fIs\fR);
.in +.5in
.sp
Returns a regular expression 
suitable for use with \fBre_compile(3)\fR
for a file specification in \fBsh(1)\fR format.
.in -.5in
.PP
.nh
char *\fBfullPath\fR(char *\fIparent\fR, char *\fIbase\fR);
.in +.5in
.sp
Returns a pointer to a static character array containing "\fIparent/base\fR".
If \fIparent\fR is not supplied, "." is used as a default.
The size of the result is limited to the maximum path length 
supported by the file system.
.in -.5in
.PP
.nh
char *\fBparentname\fR(char *\fIs\fR);
.in +.5in
.sp
Returns a pointer to a static character array containing 
the name of the parent directory of \fIs\fR.
.in -.5in
.PP
.nh
char *\fBpwd\fR()
.in +.5in
.sp
Returns a pointer to a static string containing the current working directory.
.in -.5in
.SH "SEE ALSO"
text(3)
